@@ -16,7 +16,10 @@ You need to have a public IP with a port open. That port will be 80 by default.
 Authentication is off by default but you can choose to authenticate to use some Webhook Topics or to get more information.
 
 .. note:: Please note that Your Endpoint URL has to be HTTPS if you need authentication which means that you probably
-            need a reverse proxy like nginx. This lib currently does not provide any way to add https on its own.
+            need a reverse proxy like nginx. You can also hand in a valid ssl context to be used in the constructor.
+
+You can check on whether or not your webhook is publicly reachable by navigating to the URL set in `callback_url`.
+You should get a 200 response with the text `pyTwitchAPI webhook`.
 
 
 *******************
@@ -77,7 +80,7 @@ Class Documentation:
 """
 
 
-from typing import Union, Tuple, Callable
+from typing import Union, Tuple, Callable, List, Optional
 from .helper import build_url, TWITCH_API_BASE_URL, get_uuid, get_json, make_fields_datetime, fields_to_enum
 from .helper import extract_uuid_str_from_url
 from .types import *
@@ -90,6 +93,7 @@ from logging import getLogger, Logger
 import time
 from .twitch import Twitch
 from concurrent.futures._base import CancelledError
+from ssl import SSLContext
 
 
 class TwitchWebHook:
@@ -98,6 +102,7 @@ class TwitchWebHook:
     :param str callback_url: The full URL of the webhook.
     :param str api_client_id: The id of your API client
     :param int port: the port on which this webhook should run
+    :param ~ssl.SSLContext ssl_context: optional ssl context to be used |default| :code:`None`
     :var str secret: A random secret string. Set this for added security.
     :var str callback_url: The full URL of the webhook.
     :var int subscribe_least_seconds: The duration in seconds for how long you want to subscribe to webhhoks.
@@ -123,6 +128,7 @@ class TwitchWebHook:
     _host: str = '0.0.0.0'
     __twitch: Twitch = None
     __task_refresh = None
+    __ssl_context = None
     __client_id = None
     __running = False
     __callbacks = {}
@@ -133,10 +139,11 @@ class TwitchWebHook:
     __hook_runner: Union['web.AppRunner', None] = None
     __logger: Logger = None
 
-    def __init__(self, callback_url: str, api_client_id: str, port: int):
+    def __init__(self, callback_url: str, api_client_id: str, port: int, ssl_context: Optional[SSLContext] = None):
         self.callback_url = callback_url
         self.__client_id = api_client_id
         self._port = port
+        self.__ssl_context = ssl_context
         self.__logger = getLogger('twitchAPI.webhook')
 
     def authenticate(self, twitch: Twitch) -> None:
@@ -169,7 +176,8 @@ class TwitchWebHook:
                              web.get('/hypetrain/events', self.__handle_challenge),
                              web.post('/hypetrain/events', self.__handle_hypetrain_events),
                              web.get('/subscriptions/events', self.__handle_challenge),
-                             web.post('/subscriptions/events', self.__handle_subscription_events)])
+                             web.post('/subscriptions/events', self.__handle_subscription_events),
+                             web.get('/', self.__handle_default)])
         hook_runner = web.AppRunner(hook_app)
         return hook_runner
 
@@ -178,7 +186,7 @@ class TwitchWebHook:
         self.__hook_loop = asyncio.new_event_loop()
         asyncio.set_event_loop(self.__hook_loop)
         self.__hook_loop.run_until_complete(runner.setup())
-        site = web.TCPSite(runner, str(self._host), self._port)
+        site = web.TCPSite(runner, str(self._host), self._port, ssl_context=self.__ssl_context)
         self.__hook_loop.run_until_complete(site.start())
         self.__logger.info('started twitch API hook on port ' + str(self._port))
         # add refresh task
@@ -284,7 +292,15 @@ class TwitchWebHook:
             self.__logger.error(f'Subscription failed! status code: {result.status_code}, body: {result.text}')
         return result.status_code == 202
 
-    def _generic_subscribe(self, callback_path: str, url: str, uuid: UUID, callback_func) -> bool:
+    def _generic_subscribe(self,
+                           callback_path: str,
+                           url: str,
+                           uuid: UUID,
+                           callback_func,
+                           auth_type: AuthType,
+                           auth_scope: List[AuthScope]) -> bool:
+        if not self.__twitch.has_required_auth(auth_type, auth_scope):
+            raise UnauthorizedException('required authentication not set or missing auth scope')
         success = self._subscribe(callback_path+"?uuid=" + str(uuid), url)
         if success:
             self.__add_callable(uuid, callback_func)
@@ -403,14 +419,17 @@ class TwitchWebHook:
         :param from_id: str or None
         :param to_id: str or None
         :param callback_func: function for callback
+        :raises ValueError: if both from_id and to_id are None
         :rtype: bool, UUID
         """
+        if from_id is None and to_id is None:
+            raise ValueError('specify at least one of from_id and to_id')
         param_dict = {"first": 1,
                       "from_id": from_id,
                       "to_id": to_id}
         url = build_url(TWITCH_API_BASE_URL + "users/follows", param_dict, remove_none=True)
         uuid = get_uuid()
-        return self._generic_subscribe('/users/follows', url, uuid, callback_func), uuid
+        return self._generic_subscribe('/users/follows', url, uuid, callback_func, AuthType.NONE, []), uuid
 
     def subscribe_stream_changed(self,
                                  user_id: str,
@@ -425,7 +444,7 @@ class TwitchWebHook:
         param_dict = {"user_id": user_id}
         url = build_url(TWITCH_API_BASE_URL + "streams", param_dict)
         uuid = get_uuid()
-        return self._generic_subscribe('/streams', url, uuid, callback_func), uuid
+        return self._generic_subscribe('/streams', url, uuid, callback_func, AuthType.NONE, []), uuid
 
     def subscribe_user_changed(self,
                                user_id: str,
@@ -440,7 +459,7 @@ class TwitchWebHook:
         param_dict = {"id": user_id}
         url = build_url(TWITCH_API_BASE_URL + "users", param_dict)
         uuid = get_uuid()
-        return self._generic_subscribe('/users/changed', url, uuid, callback_func), uuid
+        return self._generic_subscribe('/users/changed', url, uuid, callback_func, AuthType.USER, []), uuid
 
     def subscribe_extension_transaction_created(self,
                                                 extension_id: str,
@@ -462,7 +481,7 @@ class TwitchWebHook:
         }
         url = build_url(TWITCH_API_BASE_URL + 'extensions/transactions', params)
         uuid = get_uuid()
-        return self._generic_subscribe('/extensions/transactions', url, uuid, callback_func), uuid
+        return self._generic_subscribe('/extensions/transactions', url, uuid, callback_func, AuthType.APP, []), uuid
 
     def subscribe_moderator_change_events(self,
                                           broadcaster_id: str,
@@ -483,7 +502,12 @@ class TwitchWebHook:
         }
         url = build_url(TWITCH_API_BASE_URL + 'moderation/moderators/events', params, remove_none=True)
         uuid = get_uuid()
-        return self._generic_subscribe('/moderation/moderators/events', url, uuid, callback_func), uuid
+        return self._generic_subscribe('/moderation/moderators/events',
+                                       url,
+                                       uuid,
+                                       callback_func,
+                                       AuthType.USER,
+                                       []), uuid
 
     def subscribe_channel_ban_change_events(self,
                                             broadcaster_id: str,
@@ -504,7 +528,7 @@ class TwitchWebHook:
         }
         url = build_url(TWITCH_API_BASE_URL + 'moderation/banned/events', params, remove_none=True)
         uuid = get_uuid()
-        return self._generic_subscribe('/moderation/banned/events', url, uuid, callback_func), uuid
+        return self._generic_subscribe('/moderation/banned/events', url, uuid, callback_func, AuthType.USER, []), uuid
 
     def subscribe_subscription_events(self,
                                       broadcaster_id: str,
@@ -531,7 +555,12 @@ class TwitchWebHook:
         }
         url = build_url(TWITCH_API_BASE_URL + 'subscriptions/events', params, remove_none=True)
         uuid = get_uuid()
-        return self._generic_subscribe('/subscriptions/events', url, uuid, callback_func), uuid
+        return self._generic_subscribe('/subscriptions/events',
+                                       url,
+                                       uuid,
+                                       callback_func,
+                                       AuthType.USER,
+                                       [AuthScope.CHANNEL_READ_SUBSCRIPTIONS]), uuid
 
     def subscribe_hype_train_events(self,
                                     broadcaster_id: str,
@@ -549,7 +578,12 @@ class TwitchWebHook:
         }
         url = build_url(TWITCH_API_BASE_URL + 'hypetrain/events', params)
         uuid = get_uuid()
-        return self._generic_subscribe('/hypetrain/events', url, uuid, callback_func), uuid
+        return self._generic_subscribe('/hypetrain/events',
+                                       url,
+                                       uuid,
+                                       callback_func,
+                                       AuthType.USER,
+                                       [AuthScope.CHANNEL_READ_HYPE_TRAIN]), uuid
 
     # ==================================================================================================================
     # HANDLERS
